<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


/*
 * if no pro performer, then redirect to /login
 * [Cell Number] [Password] field -> proLogInWithPassword -> /pro/dashboard
 * -> they are authenticated in... see the home dashboard... logout button to -> /login
 */


Route::get('login', 'LoginController@showLoginForm')->name('login');
Route::post('login', 'LoginController@login');
Route::post('logout', 'LoginController@logout')->name('logout');

Route::middleware('pro.auth')->group(function () {

    Route::get('/blank', 'HomeController@blank')->name('blank');

    Route::get('/', 'HomeController@dashboard')->name('dashboard');

    Route::get('/new-patient', 'HomeController@newPatient')->name('new-patient');

    Route::get('/patients', 'HomeController@patients')->name('patients');

    Route::name('practice-management.')->prefix('practice-management')->group(function () {
        Route::get('rates', 'PracticeManagementController@rates')->name('rates');
        Route::get('dashboard', 'PracticeManagementController@dashboard')->name('dashboard');
        Route::get('previous-bills', 'PracticeManagementController@previousBills')->name('previousBills');
        Route::get('financial-transactions', 'PracticeManagementController@financialTransactions')->name('financialTransactions');
        Route::get('pending-bills-to-sign', 'PracticeManagementController@pendingBillsToSign')->name('pendingBillsToSign');
        Route::get('hr', 'PracticeManagementController@hr')->name('hr');
        Route::get('direct-deposit-settings', 'PracticeManagementController@directDepositSettings')->name('directDepositSettings');
        Route::get('w9', 'PracticeManagementController@w9')->name('w9');
        Route::get('contract', 'PracticeManagementController@contract')->name('contract');
    });

    Route::name('patients.view.')->prefix('patients/view/{patient}')->group(function () {
        Route::get('intake', 'PatientController@intake')->name('intake');
        Route::get('', 'PatientController@dashboard')->name('dashboard');
        Route::get('care-plan', 'PatientController@carePlan')->name('care-plan');
        Route::get('medications', 'PatientController@medications')->name('medications');
        Route::get('dx-and-focus-areas', 'PatientController@dxAndFocusAreas')->name('dx-and-focus-areas');
        Route::get('care-team', 'PatientController@careTeam')->name('care-team');
        Route::get('measurements', 'PatientController@measurements')->name('measurements');
        Route::get('labs-and-studies', 'PatientController@labsAndStudies')->name('labs-and-studies');
        Route::get('history', 'PatientController@history')->name('history');
        Route::get('immunizations', 'PatientController@immunizations')->name('immunizations');
        Route::get('allergies', 'PatientController@allergies')->name('allergies');
        Route::get('notes', 'PatientController@notes')->name('notes');
        Route::name('notes.view.')->prefix('notes/view/{note}')->group(function () {
            Route::get('', 'NoteController@dashboard')->name('dashboard');
        });
        Route::get('flowsheets', 'PatientController@flowSheets')->name('flowsheets');
        Route::get('demographics', 'PatientController@demographics')->name('demographics');
        Route::get('account', 'PatientController@account')->name('account');
        Route::get('care-checklist', 'PatientController@careChecklist')->name('care-checklist');
        Route::get('documents', 'PatientController@documents')->name('documents');
        Route::get('education', 'PatientController@education')->name('education');
        Route::get('messaging', 'PatientController@messaging')->name('messaging');
        Route::get('duplicate', 'PatientController@duplicate')->name('duplicate');
        Route::get('care-months', 'PatientController@careMonths')->name('care-months');
        Route::name('care-months.view.')->prefix('care-months/view/{careMonth}')->group(function () {
            Route::get('', 'CareMonthController@dashboard')->name('dashboard');
        });
    });

    // AJAX presence poll
    Route::get('/patients/{patient}/presence', 'PatientController@presence');

    // 2-pane outer page housing lhs (practice management) and rhs (video call)
    Route::get('/mc/{fragment?}', 'HomeController@mc')
        ->where('fragment', '.*')
        ->name('mc');

    // pro meeting
    Route::get('/pro/meet/{uid?}', 'PracticeManagementController@meet');
    Route::get('/pro/get-opentok-session-key/{uid}', 'PracticeManagementController@getOpentokSessionKey');

    //Notes stuff
    Route::get('/note/{note_uid}', 'NoteController@renderNote')->name('render-note');
    Route::get('/section_create_form/{note_uid}/{section_template_uid}', 'NoteController@sectionCreateForm')->name('section_create_form');
    Route::get('/section_update_form/{section_uid}', 'NoteController@sectionUpdateForm')->name('section_update_form');
    Route::post("/process_form_submit", 'NoteController@processFormSubmit')->name('process_form_submit');
});
